﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

using KendoTest1.Models;

namespace KendoTest1.Controllers
{
	public class HomeController : Controller
	{
		public ActionResult Index()
		{
			ViewBag.Message = "Welcome to ASP.NET MVC with Telerik Kendo UI!";

			return (View());
		}

		public ActionResult Family()
		{
			List<TestModel> data = new List<TestModel>();
			
			string error = null;
			string filter = GetFilter();

			try
			{
				TestModel item = null;

				item = new TestModel(10, "Robert", "Paul", "Manning", DateTime.Parse("05/21/1959"));
				data.Add(item);

				item = new TestModel(20, "Leigh", "Harrington", "Manning", DateTime.Parse("06/03/1961"));
				data.Add(item);

				item = new TestModel(30, "Jonathan", "David", "Manning", DateTime.Parse("08/17/1985"));
				data.Add(item);

				item = new TestModel(40, "Hannah", "Katherine", "Manning", DateTime.Parse("06/15/1989"));
				data.Add(item);

				item = new TestModel(50, "Benjamin", "Andrew", "Manning", DateTime.Parse("01/13/1992"));
				data.Add(item);

				item = new TestModel(60, "Anne", "Elisabeth", "Manning", DateTime.Parse("03/22/1996"));
				data.Add(item);
			}
			catch (Exception e)
			{
				error = e.Message;
			}

			int count = data.Count;

			return (Json(new { data, count, filter, error }, JsonRequestBehavior.AllowGet));
		}

		public ActionResult About()
		{
			return (View());
		}

		private string GetFilter()
		{
			try
			{
				string filter = String.Empty;
				string filterLogic = Request.Params["filter[logic]"];
				List<object> filterValues = new List<object>();

				if (!String.IsNullOrEmpty(filterLogic))
				{
					for (int index = 0; index < 32; index += 1)
					{
						string fieldKey = String.Format("filter[filters][{0}][field]", index);
						string operatorKey = String.Format("filter[filters][{0}][operator]", index);
						string valueKey = String.Format("filter[filters][{0}][value]", index);

						string fieldName = Request.Params[fieldKey];
						string operatorName = Request.Params[operatorKey];
						string value = Request.Params[valueKey];

						string segment = String.Empty;

						if (String.IsNullOrEmpty(fieldName))
						{
							break;
						}

						if (String.IsNullOrEmpty(operatorName))
						{
							break;
						}

						if (String.IsNullOrEmpty(value))
						{
							value = "NULL";
						}

						if (filter.Length > 0)
						{
							filter += String.Format(" {0} ", filterLogic);
						}

						switch (operatorName.ToLower())
						{
							case "equal":
							case "eq":
							case "==":
							case "=":
								segment = String.Format("{0} = {1}", fieldName, value);
								break;

							case "greaterthan":
							case "gt":
							case ">":
								segment = String.Format("{0} > {1}", fieldName, value);
								break;

							case "greaterthanorequal":
							case "gte":
							case "ge":
							case ">=":
								segment = String.Format("{0} >= {1}", fieldName, value);
								break;

							case "lessthan":
							case "lt":
							case "<":
								segment = String.Format("{0} < {1}", fieldName, value);
								break;

							case "lessthanorequal":
							case "lte":
							case "le":
							case "<=":
								segment = String.Format("{0} <= {1}", fieldName, value);
								break;

							case "notequal":
							case "neq":
							case "ne":
							case "!=":
							case "<>":
								segment = String.Format("{0} != {1}", fieldName, value);
								break;

							case "contains":
							case "like":
								segment = String.Format("{0}.Contains(\"{1}\")", fieldName, value);
								break;

							case "endswith":
							case "ends":
								segment = String.Format("{0}.EndsWith(\"{1}\")", fieldName, value);
								break;

							case "startswith":
							case "beginswith":
							case "begins":
								segment = String.Format("{0}.StartsWith(\"{1}\")", fieldName, value);
								break;

							default:
								break;
						}

						filter += segment;
					}
				}

				return (filter);
			}
			catch (Exception e)
			{
				return (e.Message);
			}

		}
	}
}
